==> MacOSX10.11.sdk.zip: MacOSX10.11.sdk/System/Library/Frameworks/Quartz.framework/Versions/A/Frameworks/PDFKit.framework/Versions/A/Headers/PDFBorder.h <==
// =====================================================================================================================
//  PDFBorder.h
// =====================================================================================================================


#import <AppKit/AppKit.h>


@class PDFBorderPrivateVars;


// Style in which PDFBorder is displayed.
typedef NSInteger PDFBorderStyle;
enum
{
    kPDFBorderStyleSolid = 0, 
    kPDFBorderStyleDashed = 1, 
    kPDFBorderStyleBeveled = 2, 
    kPDFBorderStyleInset = 3, 
    kPDFBorderStyleUnderline = 4
};


@interface PDFBorder : NSObject <NSCopying, NSCoding>
{
@private
	PDFBorderPrivateVars *_pdfPriv;
}

// -------- accessors

// See styles above. Whether border is drawn solid, dashed etc.
- (PDFBorderStyle) style;
- (void) setStyle: (PDFBorderStyle) style;

// Width of line used to strok border.
- (CGFloat) lineWidth;
- (void) setLineWidth: (CGFloat) width;

// For rounded-rect borders, the corner radii.  Widget annotations generally do not specify a corder radius.
//- (CGFloat) horizontalCornerRadius;						DEPRECATED
//- (void) setHorizontalCornerRadius: (CGFloat) radius;		DEPRECATED
//- (CGFloat) verticalCornerRadius;							DEPRECATED
//- (void) setVerticalCornerRadius: (CGFloat) radius;		DEPRECATED

// Array of floats specifying the dash pattern (see NSBezierPath for more detail).
- (NSArray *) dashPattern;
- (void) setDashPattern: (NSArray *) pattern;

// Draw method.  Not generally needed since the annotations themselves call this method when they are drawn.
// Call -[NSColor set] before calling (the various annotations do this often calling -[PDFAnnotation color] or whatever 
// is appropriate for their class.
- (void) drawInRect: (NSRect) rect;

@end

==> MacOSX10.12.sdk.zip: MacOSX10.12.sdk/System/Library/Frameworks/Quartz.framework/Versions/A/Frameworks/PDFKit.framework/Versions/A/Headers/PDFBorder.h <==
// =====================================================================================================================
//  PDFBorder.h
// =====================================================================================================================


#import <PDFKit/PDFKitPlatform.h>

NS_ASSUME_NONNULL_BEGIN

@class PDFBorderPrivateVars;

// Style in which PDFBorder is displayed.
NS_ENUM_AVAILABLE_MAC(10_4)
typedef NS_ENUM(NSInteger, PDFBorderStyle)
{
    kPDFBorderStyleSolid = 0, 
    kPDFBorderStyleDashed = 1, 
    kPDFBorderStyleBeveled = 2, 
    kPDFBorderStyleInset = 3, 
    kPDFBorderStyleUnderline = 4
};

// PDFBorder is not directly an annotation, but instead is a supportive structure common to a few annotations
NS_CLASS_AVAILABLE_MAC(10_4)
@interface PDFBorder : NSObject <NSCopying, NSCoding>
{
@private
	PDFBorderPrivateVars *_private;
}

// -------- accessors

// See styles above. Whether border is drawn solid, dashed etc.
@property(nonatomic, assign) PDFBorderStyle style;

// Width of line used to strok border.
@property(nonatomic, assign) CGFloat lineWidth;

// Array of floats specifying the dash pattern (see NSBezierPath for more detail).
@property(nonatomic, retain, nullable) NSArray* dashPattern;

// Draw method.  Not generally needed since the annotations themselves call this method when they are drawn.
// Call -[NSColor set] before calling (the various annotations do this often calling -[PDFAnnotation color] or whatever 
// is appropriate for their class.
- (void) drawInRect: (PDFRect) rect;

@end

NS_ASSUME_NONNULL_END
